package SPVM::Sys::Signal::Handler::Unknwon;

1;

=head1 Name

SPVM::Sys::Signal::Handler::Unknwon - Signal Handler that is unknwon.

=head1 Usage

  use Sys::Signal::Handler::Unknwon;

=head1 Description

C<Sys::Signal::Handler::Unknwon> is a signal handler that is unknwon.

See L<signal(2) - Linux man page|https://linux.die.net/man/2/signal> in Linux.

See L<Sys::Signal|SPVM::Sys::Signal> about the details of signals.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

